@@ -12,16 +12,16 @@ echo 0 > /proc/sys/kernel/printk
 # here, you can load modules depending on the kernel version
 case $(uname -r) in
     2.6*) kernelmodules="$kernelmodules mptspi dm-mod md-mod aes dm-crypt" ;;
-      3*) kernelmodules="$kernelmodules mptspi dm-mod md-mod aes dm-crypt" ;;
-      4*) kernelmodules="$kernelmodules mptspi dm-mod md-mod aes dm-crypt" ;;
+    [3456]*) kernelmodules="$kernelmodules mptspi dm-mod md-mod aes dm-crypt" ;;
 esac
 
 for mod in $kernelmodules; do
-    [ "$verbose" ] && echo Loading kernel module $mod
+    [ X$verbose = X1 ] && echo Loading kernel module $mod
     modprobe -a $mod 1>/dev/null 2>&1
 done
 
-ip ad show up | egrep -iv 'loopback|127.0.0.1|::1/128|_lft'
+# show the basic information about the network interface
+ip -br li show up|egrep -v ^lo; ip -br a show up|egrep -v ^lo
 
 echo $printk > /proc/sys/kernel/printk
 
