@@ -1,4 +1,3 @@
-
 #! /bin/bash
 
 # parse *.profile and build a curses menu, so the user can select a profile
@@ -15,8 +14,8 @@ fi
 [ "$flag_menu" ] || return 0
 
 out=$(tty)
-tempfile=`(tempfile) 2>/dev/null`
-tempfile2=`(tempfile) 2>/dev/null`
+tempfile=$(mktemp)
+tempfile2=$(mktemp)
 trap "rm -f $tempfile $tempfile2" EXIT INT QUIT
 
 # declare the data structure, use associative arrays
