@@ -73,6 +73,9 @@ sub find_all_phys_devs {
     } elsif ($config eq "TMPFS") {
       # no devices
       next;
+    } elsif ($config eq "NFS") {
+      # no devices
+      next;
     } else {
       &FAI::internal_error("Unexpected key $config");
     }
@@ -394,15 +397,27 @@ sub get_current_disks {
 ################################################################################
 #
 # @brief Collect the current LVM configuration
-#
+# use enviroment variable SS_IGNORE_VG to ignore a list of volume groups
 ################################################################################
 sub get_current_lvm {
 
   use Linux::LVM;
+  Linux::LVM->units('H');
   use Cwd qw(abs_path);
 
+  # create hash of vgs to be ignored
+  my %vgignore = ();
+  if (defined $ENV{"SS_IGNORE_VG"}) {
+    %vgignore = map { $_ , 1} split ' ',$ENV{"SS_IGNORE_VG"};
+  }
+
   # get the existing volume groups
   foreach my $vg (get_volume_group_list()) {
+    if ($vgignore{$vg}) {
+      warn "Ignoring volume group: $vg\n";
+      next;
+    }
+
     # initialise the hash entry
     $FAI::current_lvm_config{$vg}{physical_volumes} = ();
 
@@ -493,7 +508,7 @@ sub get_current_raid {
   # parse the output line by line
   foreach my $line (@mdadm_print) {
     print MDADM_EX "$line";
-    if ($line =~ /^ARRAY \/dev\/md[\/]?(\d+)\s+/) {
+    if ($line =~ /^ARRAY \/dev\/md[\/]?([\w-]+)\s+/) {
       $id = $1;
 
       foreach (split (" ", $line)) {
@@ -684,6 +699,9 @@ sub propagate_and_check_preserve {
     } elsif ($config eq "TMPFS") {
       # We don't do preserve for tmpfs
       next;
+    } elsif ($config eq "NFS") {
+      # We don't do preserve for nfs
+      next;
     } else {
       &FAI::internal_error("Unexpected key $config");
     }
